@@ -6,8 +6,7 @@ get_xy_s <- function(x, y, val, inches, symbol) {
     val_max = max(val),
     symbol = symbol
   )
-  sizesi <- xinch(sizes)
-
+  sizesi <- yinch(sizes)
   x <- rep(x + sizesi[1], length(val))
   y <- y - sizesi[1] * 2 + sizesi
   h <- sizesi[1] * 2
